mod r#async;
mod bool32;
mod bstr;
mod build;
mod callback;
mod class;
mod com_interface;
mod constant;
mod delegate;
mod r#enum;
mod function;
mod gen;
mod guid;
mod handle;
mod helpers;
mod interface;
mod interface_info;
mod iterator;
mod matrix3x2;
mod matrix4x4;
mod name;
mod ntstatus;
mod object;
mod propertykey;
mod pstr;
mod pwstr;
mod r#struct;
mod sys;
mod timespan;
mod to_ident;
mod tree;
mod vector2;
mod vector3;
mod vector4;
mod win32;
mod win32_error;
mod winrt;

// TODO: These public things are mostly/all used by the implement macro
// move that logic into here so the macro crate is just forwarding to the gen crate
pub use build::*;
pub use gen::*;
pub use helpers::*;
pub use interface_info::*;
pub use name::*;
pub use to_ident::*;
pub use tree::*;
pub use win32::*;
pub use winrt::*;

use bool32::*;
use bstr::*;
use callback::*;
use class::*;
use com_interface::*;
use constant::*;
use delegate::*;
use function::*;
use guid::*;
use handle::*;
use interface::*;
use iterator::*;
use matrix3x2::*;
use matrix4x4::*;
use ntstatus::*;
use object::*;
use propertykey::*;
use pstr::*;
use pwstr::*;
use quote::*;
use r#async::*;
use r#enum::*;
use r#struct::*;
use reader::*;
use sys::*;
use timespan::*;
use vector2::*;
use vector3::*;
use vector4::*;
use win32_error::*;
